from setuptools import setup

setup(name='tad_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['tad_distributions'],
      zip_safe=False)
